@@ -39,6 +39,12 @@ func TestAllBuildTargets(t *testing.T) {
 			"hardfloat",
 			"softfloat",
 		},
+		Goamd64: []string{
+			"v1",
+			"v2",
+			"v3",
+			"v4",
+		},
 		Ignore: []config.IgnoredBuild{
 			{
 				Goos:   "linux",
@@ -53,6 +59,9 @@ func TestAllBuildTargets(t *testing.T) {
 			}, {
 				Goarch: "mips64le",
 				Gomips: "softfloat",
+			}, {
+				Goarch:  "amd64",
+				Goamd64: "v3",
 			},
 		},
 	}
@@ -62,7 +71,9 @@ func TestAllBuildTargets(t *testing.T) {
 		require.NoError(t, err)
 		require.Equal(t, []string{
 			"linux_386",
-			"linux_amd64",
+			"linux_amd64_v1",
+			"linux_amd64_v2",
+			"linux_amd64_v4",
 			"linux_arm_6",
 			"linux_arm64",
 			"linux_mips_hardfloat",
@@ -72,18 +83,26 @@ func TestAllBuildTargets(t *testing.T) {
 			"linux_mipsle_softfloat",
 			"linux_mips64le_hardfloat",
 			"linux_riscv64",
-			"darwin_amd64",
+			"darwin_amd64_v1",
+			"darwin_amd64_v2",
+			"darwin_amd64_v4",
 			"darwin_arm64",
 			"freebsd_386",
-			"freebsd_amd64",
+			"freebsd_amd64_v1",
+			"freebsd_amd64_v2",
+			"freebsd_amd64_v4",
 			"freebsd_arm_6",
 			"freebsd_arm_7",
 			"freebsd_arm64",
 			"openbsd_386",
-			"openbsd_amd64",
+			"openbsd_amd64_v1",
+			"openbsd_amd64_v2",
+			"openbsd_amd64_v4",
 			"openbsd_arm64",
 			"windows_386",
-			"windows_amd64",
+			"windows_amd64_v1",
+			"windows_amd64_v2",
+			"windows_amd64_v4",
 			"windows_arm_6",
 			"windows_arm_7",
 			"js_wasm",
@@ -95,7 +114,9 @@ func TestAllBuildTargets(t *testing.T) {
 		require.NoError(t, err)
 		require.Equal(t, []string{
 			"linux_386",
-			"linux_amd64",
+			"linux_amd64_v1",
+			"linux_amd64_v2",
+			"linux_amd64_v4",
 			"linux_arm_6",
 			"linux_arm64",
 			"linux_mips_hardfloat",
@@ -105,18 +126,26 @@ func TestAllBuildTargets(t *testing.T) {
 			"linux_mipsle_softfloat",
 			"linux_mips64le_hardfloat",
 			"linux_riscv64",
-			"darwin_amd64",
+			"darwin_amd64_v1",
+			"darwin_amd64_v2",
+			"darwin_amd64_v4",
 			"darwin_arm64",
 			"freebsd_386",
-			"freebsd_amd64",
+			"freebsd_amd64_v1",
+			"freebsd_amd64_v2",
+			"freebsd_amd64_v4",
 			"freebsd_arm_6",
 			"freebsd_arm_7",
 			"freebsd_arm64",
 			"openbsd_386",
-			"openbsd_amd64",
+			"openbsd_amd64_v1",
+			"openbsd_amd64_v2",
+			"openbsd_amd64_v4",
 			"openbsd_arm64",
 			"windows_386",
-			"windows_amd64",
+			"windows_amd64_v1",
+			"windows_amd64_v2",
+			"windows_amd64_v4",
 			"windows_arm_6",
 			"windows_arm_7",
 			"windows_arm64",
@@ -126,8 +155,9 @@ func TestAllBuildTargets(t *testing.T) {
 
 	t.Run("invalid goos", func(t *testing.T) {
 		_, err := matrix(config.Build{
-			Goos:   []string{"invalid"},
-			Goarch: []string{"amd64"},
+			Goos:    []string{"invalid"},
+			Goarch:  []string{"amd64"},
+			Goamd64: []string{"v2"},
 		}, []byte("go version go1.18.0"))
 		require.EqualError(t, err, "invalid goos: invalid")
 	})
@@ -157,6 +187,15 @@ func TestAllBuildTargets(t *testing.T) {
 		}, []byte("go version go1.18.0"))
 		require.EqualError(t, err, "invalid gomips: invalid")
 	})
+
+	t.Run("invalid goamd64", func(t *testing.T) {
+		_, err := matrix(config.Build{
+			Goos:    []string{"linux"},
+			Goarch:  []string{"amd64"},
+			Goamd64: []string{"invalid"},
+		}, []byte("go version go1.18.0"))
+		require.EqualError(t, err, "invalid goamd64: invalid")
+	})
 }
 
 func TestGoosGoarchCombos(t *testing.T) {
@@ -212,7 +251,7 @@ func TestGoosGoarchCombos(t *testing.T) {
 	}
 	for _, p := range platforms {
 		t.Run(fmt.Sprintf("%v %v valid=%v", p.os, p.arch, p.valid), func(t *testing.T) {
-			require.Equal(t, p.valid, valid(target{p.os, p.arch, "", ""}))
+			require.Equal(t, p.valid, valid(target{p.os, p.arch, "", "", ""}))
 		})
 	}
 }
@@ -222,27 +261,30 @@ func TestList(t *testing.T) {
 		targets, err := List(config.Build{
 			Goos:     []string{"linux"},
 			Goarch:   []string{"amd64"},
+			Goamd64:  []string{"v2"},
 			GoBinary: "go",
 		})
 		require.NoError(t, err)
-		require.Equal(t, []string{"linux_amd64"}, targets)
+		require.Equal(t, []string{"linux_amd64_v2"}, targets)
 	})
 
 	t.Run("success with dir", func(t *testing.T) {
 		targets, err := List(config.Build{
 			Goos:     []string{"linux"},
 			Goarch:   []string{"amd64"},
+			Goamd64:  []string{"v2"},
 			GoBinary: "go",
 			Dir:      "./testdata",
 		})
 		require.NoError(t, err)
-		require.Equal(t, []string{"linux_amd64"}, targets)
+		require.Equal(t, []string{"linux_amd64_v2"}, targets)
 	})
 
 	t.Run("error with dir", func(t *testing.T) {
 		_, err := List(config.Build{
 			Goos:     []string{"linux"},
 			Goarch:   []string{"amd64"},
+			Goamd64:  []string{"v2"},
 			GoBinary: "go",
 			Dir:      "targets.go",
 		})
@@ -253,6 +295,7 @@ func TestList(t *testing.T) {
 		_, err := List(config.Build{
 			Goos:     []string{"linux"},
 			Goarch:   []string{"amd64"},
+			Goamd64:  []string{"v2"},
 			GoBinary: "nope",
 		})
 		require.EqualError(t, err, `unable to determine version of go binary (nope): exec: "nope": executable file not found in $PATH`)
