@@ -63,6 +63,9 @@ func (Pipe) Default(ctx *context.Context) error {
 		if pkg.GitSSHCommand == "" {
 			pkg.GitSSHCommand = defaultSSHCommand
 		}
+		if pkg.Goamd64 == "" {
+			pkg.Goamd64 = "v1"
+		}
 	}
 
 	return nil
@@ -97,7 +100,10 @@ func doRun(ctx *context.Context, aur config.AUR, cl client.Client) error {
 	filters := []artifact.Filter{
 		artifact.ByGoos("linux"),
 		artifact.Or(
-			artifact.ByGoarch("amd64"),
+			artifact.And(
+				artifact.ByGoarch("amd64"),
+				artifact.ByGoamd64(aur.Goamd64),
+			),
 			artifact.ByGoarch("arm64"),
 			artifact.ByGoarch("386"),
 			artifact.And(
@@ -402,13 +408,13 @@ func doPublish(ctx *context.Context, pkgs []*artifact.Artifact) error {
 
 	env := []string{fmt.Sprintf("GIT_SSH_COMMAND=%s", sshcmd)}
 
-	if err := runGitCmds(parent, env, [][]string{
+	if err := runGitCmds(ctx, parent, env, [][]string{
 		{"clone", url, cfg.Name},
 	}); err != nil {
 		return fmt.Errorf("failed to setup local AUR repo: %w", err)
 	}
 
-	if err := runGitCmds(cwd, env, [][]string{
+	if err := runGitCmds(ctx, cwd, env, [][]string{
 		// setup auth et al
 		{"config", "--local", "user.name", author.Name},
 		{"config", "--local", "user.email", author.Email},
@@ -430,7 +436,7 @@ func doPublish(ctx *context.Context, pkgs []*artifact.Artifact) error {
 	}
 
 	log.WithField("repo", url).WithField("name", cfg.Name).Info("pushing")
-	if err := runGitCmds(cwd, env, [][]string{
+	if err := runGitCmds(ctx, cwd, env, [][]string{
 		{"add", "-A", "."},
 		{"commit", "-m", msg},
 		{"push", "origin", "HEAD"},
@@ -483,10 +489,10 @@ func keyPath(key string) (string, error) {
 	return path, nil
 }
 
-func runGitCmds(cwd string, env []string, cmds [][]string) error {
+func runGitCmds(ctx *context.Context, cwd string, env []string, cmds [][]string) error {
 	for _, cmd := range cmds {
 		args := append([]string{"-C", cwd}, cmd...)
-		if _, err := git.Clean(git.RunWithEnv(env, args...)); err != nil {
+		if _, err := git.Clean(git.RunWithEnv(ctx, env, args...)); err != nil {
 			return fmt.Errorf("%q failed: %w", strings.Join(cmd, " "), err)
 		}
 	}
